![mongomtor](docs/source/_static/mongomotor.jpg)

MongoMotor is a simple-to-use, declarative-style, document-object mapper
that puts together the nice [MongoEngine](http://mongoengine.org/) API
and the clever [Motor](http://motor.readthedocs.org/en/stable/) asynchronous
approuch to create a awesome library for asynchronous access to MongoDB
using python 3.4+.

Take a look at the
[full documentation](http://mongomotor.poraodojuca.net/).
